@@ -17,7 +17,9 @@ def cli():
 
 async def _get_library(auth, **params):
     timeout = params.get("timeout")
-    async with audible.AsyncClient(auth) as client:
+    if timeout == 0:
+        timeout = None
+    async with audible.AsyncClient(auth, timeout=timeout) as client:
         library = await Library.aget_from_api(
             client,
             response_groups=(
@@ -28,9 +30,7 @@ async def _get_library(auth, **params):
                 "category_ladders, claim_code_url, is_downloaded, is_finished, "
                 "is_returnable, origin_asin, pdf_url, percent_complete, "
                 "provided_review"
-            ),
-            num_results=1000,
-            timeout=timeout
+            )
         )
     return library
 
@@ -88,10 +88,11 @@ async def _export_library(auth, **params):
                     data_row["series_title"] = v[0]["title"]
                     data_row["series_sequence"] = v[0]["sequence"]
                 elif key == "rating":
-                    data_row["rating"] = v["overall_distribution"][
-                        "display_average_rating"]
-                    data_row["num_ratings"] = v["overall_distribution"][
-                        "num_ratings"]
+                    overall_distributing = v.get("overall_distribution") or {}
+                    data_row["rating"] = overall_distributing.get(
+                        "display_average_rating", "-")
+                    data_row["num_ratings"] = overall_distributing.get(
+                        "num_ratings", "-")
                 elif key == "library_status":
                     data_row["date_added"] = v["date_added"]
                 elif key == "product_images":
@@ -119,7 +120,7 @@ async def _export_library(auth, **params):
     type=click.INT,
     default=10,
     show_default=True,
-    help="Increase the timeout time if you got any TimeoutErrors."
+    help="Increase the timeout time if you got any TimeoutErrors. Set to 0 to disable timeout."
 )
 @pass_session
 def export_library(session, **params):
@@ -138,7 +139,7 @@ def export_library(session, **params):
     type=click.INT,
     default=10,
     show_default=True,
-    help="Increase the timeout time if you got any TimeoutErrors."
+    help="Increase the timeout time if you got any TimeoutErrors. Set to 0 to disable timeout."
 )
 @pass_session
 def list_library(session, **params):
